@@ -8,23 +8,31 @@ use UseCase::User;
 
 use Types::Standard qw(Int Str);
 
-namespace user => sub {
+resource user => sub {
     params [
-        #required/optional => [name, type, default, values]
-        optional => ['start', Int, 0, qr/^\d+$/],
-        optional => ['count', Int, 10, qr/^\d+$/],
+        optional => { name => 'start', type => Int, default => 0, desc => 'Pager start' },
+        optional => { name => 'count', type => Int, default => 10, desc => 'Pager count' },
     ],
+    desc => 'List users',
     get => sub {
         my $params = shift;
         my @users = UseCase::User::list(%$params);
-        { data => RESTApp::paginate(\@users, $params) }
+        { data => paginate(\@users, $params) }
+    };
+
+    desc 'List all users',
+    get => 'all' => sub {
+        my $params = shift;
+        my @users = UseCase::User::list(%$params);
+        { data => \@users }
     };
 
     params [
-        required => ['name', Str],
-        required => ['password', Str],
-        optional => ['email', Str],
+        required => { name => 'name', type => Str, desc => 'User name' },
+        required => { name => 'password', type => Str, desc => 'User password' },
+        optional => { name => 'email', type => Str, default => undef, desc => 'User email' },
     ],
+    desc => 'Create new user',
     post => sub {
         my $params = shift;
         { success => UseCase::User::create(%$params) }
@@ -32,27 +40,31 @@ namespace user => sub {
 
     route_param id => Int,
     sub {
-        get sub {
+        desc 'Show user',
+        get => sub {
             my $params = shift;
             { data => UseCase::User::show($params->{id}) }
         };
 
         params [
-            optional => ['password', Str],
-            optional => ['email', Str],
+            optional => { name => 'password', type => Str, desc => 'User password' },
+            optional => { name => 'email', type => Str, desc => 'User email' },
         ],
+        desc => 'Edit user',
         put => sub {
             my $params = shift;
             { data => UseCase::User::edit($params->{id}, %$params) }
         };
 
-        namespace bump => sub {
-            get sub {
+        resource bump => sub {
+            desc 'Get bumps count',
+            get => sub {
                 my $params = shift;
                 { data => UseCase::User::show($params->{id})->{bumped} }
             };
 
-            put sub {
+            desc 'Bump user',
+            put => sub {
                 my $params = shift;
                 { success => UseCase::User::bump($params->{id}) }
             };
