@@ -3,7 +3,7 @@ package Raisin::Plugin::Logger;
 use strict;
 use warnings;
 
-use base 'Raisin::Plugin';
+use parent 'Raisin::Plugin';
 
 use Carp qw(carp);
 use POSIX qw(strftime);
@@ -17,7 +17,7 @@ sub build {
 
     my $obj;
     eval { $obj = Plack::Util::load_class($logger) } || do {
-        carp 'Can\'t load `Log::Dispatch. Fallback to `Raisin::Logger`!';
+        carp 'Can\'t load `Log::Dispatch`. Fallback to `Raisin::Logger`!';
         $obj = Plack::Util::load_class('Raisin::Logger');
     };
 
@@ -33,8 +33,8 @@ sub message {
     my ($self, $level, $message, @args) = @_;
 
     my $t = time;
-    my $ts = strftime "%Y-%m-%dT%H:%M:%S", localtime $t;
-    $ts .= sprintf ".%03d", ($t - int($t)) * 1000;
+    my $ts = strftime '%Y-%m-%dT%H:%M:%S', localtime $t;
+    $ts .= sprintf '.%03d', ($t - int($t)) * 1000;
 
     my $str = ref($message) ? Dumper($message) : $message;
 
